@@ -1,4 +1,4 @@
-if [ ! -f /etc/qemu-integration.conf ]
+if [ ! -e /etc/qemu-integration.conf ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/qemu-integration.conf /etc/qemu-integration.conf
